@@ -5,6 +5,7 @@
 # Licensed under the MIT License.
 
 from .tap import Tap
+from .common_note import time_align
 from ...exception import *
 
 
@@ -70,3 +71,8 @@ class Hold(Tap):
         super(Hold, self).offsetto(value)
         self.totime += value
         return self
+        
+    def align(self, bpm: float, error: int = 3, lcd = 96):
+        super(Hold, self).align(bpm, error, lcd)
+        self.totime = time_align(self.totime, bpm, error, lcd)
+        return self
